Cloning
=======

The ``clone`` module
--------------------

.. module:: bookstore.clone

.. autofunction:: build_notebook_model

.. autofunction:: build_file_model

``BookstoreCloneHandler``
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: BookstoreCloneHandler

Methods
^^^^^^^

.. automethod:: BookstoreCloneHandler.initialize

.. automethod:: BookstoreCloneHandler.get

.. automethod:: BookstoreCloneHandler.construct_template_params

.. automethod:: BookstoreCloneHandler.get_template

``BookstoreCloneAPIHandler``
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: BookstoreCloneAPIHandler

Methods
^^^^^^^

.. automethod:: BookstoreCloneAPIHandler.initialize

.. automethod:: BookstoreCloneAPIHandler.post

.. automethod:: BookstoreCloneAPIHandler.build_content_model

.. automethod:: BookstoreCloneAPIHandler.build_post_response_model
